pub enum Attribute {
Transactions,
TransferTo,
TransferFrom,
PaymentTo,
PaymentFrom,
}Expand description
The list of attributes indicates what abilities an account has.
[https://developers.akahu.nz/docs/the-account-model#attributes]
Variants
Transactions
Akahu can fetch available transactions from this account.
TransferTo
This account can receive transfers from accounts belonging to the same set of credentials.
TransferFrom
This account can initiate transfers to accounts belonging to the same set of credentials.
PaymentTo
This account can receive payments from another bank account.
PaymentFrom
This account can initiate payments to another bank account.
Implementations