pub enum BankAccountKind {
Checking,
Savings,
CreditCard,
Loan,
Kiwisaver,
Investment,
TermDeposit,
Foreign,
Tax,
Rewards,
Wallet,
}Expand description
What sort of account this is. Akahu provides specific bank account types, and falls back to more general types for other types of connection.
Variants
Checking
An everyday spending account.
Savings
A savings account.
NOTE: A savings account is not necessarily a regular bank account. It might not have transactions associated, or be able to receive payments. Check the attributes field to see what this account can do.
CreditCard
A credit card.
Loan
A loan account.
Kiwisaver
A KiwiSaver investment product.
Investment
A general investment product.
TermDeposit
A term deposit.
Foreign
An account holding a foreign currency.
Tax
An account with tax authorities.
Rewards
An account for rewards points, e.g. Fly Buys or True Rewards.
Wallet
Available cash for investment or withdrawal from an investment provider.
Implementations