pub enum TransactionKind {
Show 14 variants
Credit,
Debit,
Payment,
Transfer,
StandingOrder,
Eftpos,
Interest,
Fee,
Tax,
CreditCard,
DirectDebit,
DirectCredit,
Atm,
Loan,
}Expand description
What sort of transaction this is. Akahu tries to find a specific transaction type, falling back to “CREDIT” or “DEBIT” if nothing else is available.
[https://developers.akahu.nz/docs/the-transaction-model#type]
Variants
Credit
Money has entered the account.
Debit
Money has left the account.
Payment
A payment to an external account.
Transfer
A transfer between accounts that are associated with the same credentials.
StandingOrder
An automatic payment.
Eftpos
A payment made via the EFTPOS system.
Interest
An interest payment from the account provider.
Fee
A fee from the account provider.
Tax
A tax payment.
CreditCard
A credit card payment.
DirectDebit
A direct debit payment.
DirectCredit
A direct credit (someone paying into the account).
Atm
An ATM deposit or withdrawal.
Loan
A payment related to a loan.
Implementations