AccountMetadata

Struct AccountMetadata 

pub struct AccountMetadata {
    pub holder: Option<String>,
    pub has_unlisted_holders: Option<bool>,
    pub payment_details: Option<PaymentDetails>,
    pub loan_details: Option<LoanDetails>,
    pub breakdown: Option<Value>,
    pub portfolio: Option<Value>,
}
This is a less defined part of our API that lets us expose data that may be specific to certain account types or financial institutions. An investment provider, for example, may expose a breakdown of investment results.

Akahu standardises this metadata as much as possible. However depending on the specific integration and account, some data fields may be unavailable or poorly specified. Treat all fields in the meta object as optional.

[https://developers.akahu.nz/docs/the-account-model#meta]

Fields

holder: Option<String>

The account holder name as exposed by the provider. In the case of bank accounts this is the name on the bank statement.

has_unlisted_holders: Option<bool>

Indicates if the account has other holders that are not listed in the holder field. This only applies to official open banking connections where the institution indicates a joint account, but only provides the authorising party’s name.

payment_details: Option<PaymentDetails>

If the account can be paid but is not a bank account (for example a KiwiSaver account), this field will have payment details.

loan_details: Option<LoanDetails>

Includes detailed information related to a loan account (if available from the loan provider).

breakdown: Option<Value>

An investment breakdown. Details are passed straight through from integrations, making them very inconsistent.

portfolio: Option<Value>

An investment portfolio. Details are passed through from integrations, so some are missing various fields. A maximum of 200 funds/instruments are supported per investment account.