pub struct BalanceDetails {
pub current: Decimal,
pub available: Option<Decimal>,
pub limit: Option<Decimal>,
pub overdrawn: Option<bool>,
pub currency: Currency,
}Expand description
The account balance.
[https://developers.akahu.nz/docs/the-account-model#balance]
Fields
current: DecimalThe current account balance.
A negative balance indicates the amount owed to the account issuer. For example a checking account in overdraft will have a negative balance, same as the amount owed on a credit card or the principal remaining on a loan.
available: Option<Decimal>The balance that is currently available to the account holder.
limit: Option<Decimal>The credit limit for this account.
For example a credit card limit or an overdraft limit. This value is only present when provided directly by the connected financial institution.
overdrawn: Option<bool>A boolean indicating whether this account is in overdraft.
currency: CurrencyThe 3 letter ISO 4217 currency code that this balance is in (e.g. NZD).