pub struct PendingTransaction {
pub account: AccountId,
pub connection: ConnectionId,
pub updated_at: DateTime<Utc>,
pub date: DateTime<Utc>,
pub description: String,
pub amount: Decimal,
pub kind: TransactionKind,
pub meta: Option<TransactionMeta>,
}Expand description
A pending transaction that has not yet been settled.
Pending transactions are not stable - the date or description may change due to the unreliable nature of underlying NZ bank data. They are not assigned unique identifiers and are not enriched by Akahu.
[https://developers.akahu.nz/docs/accessing-transactional-data#pending-transactions]
Fields
account: AccountIdThe account this pending transaction belongs to.
connection: ConnectionIdThis is the ID of provider that Akahu has retrieved this transaction from.
updated_at: DateTime<Utc>The time that this pending transaction was last updated (as an ISO 8601 timestamp).
date: DateTime<Utc>The date that the transaction was posted with the account holder, as an ISO 8601 timestamp. May change before the transaction settles.
description: StringThe transaction description as provided by the bank. May change before settlement.
amount: DecimalThe amount of money that will be moved by this transaction.
kind: TransactionKindWhat sort of transaction this is.
meta: Option<TransactionMeta>Additional metadata about the transaction.