RefreshDetails

Struct RefreshDetails 

pub struct RefreshDetails {
    pub balance: Option<DateTime<Utc>>,
    pub meta: Option<DateTime<Utc>>,
    pub transactions: Option<DateTime<Utc>>,
    pub party: Option<DateTime<Utc>>,
}
Akahu can refresh different parts of an account’s data at different rates. The timestamps in the refreshed object tell you when that account data was last updated.

When looking at a timestamp in here, you can think “Akahu’s view of the account (balance/metadata/transactions) is up to date as of $TIME”.

[https://developers.akahu.nz/docs/the-account-model#refreshed]

Fields

balance: Option<DateTime<Utc>>

When the balance was last updated.

meta: Option<DateTime<Utc>>

When other account metadata was last updated (any account property apart from balance).

transactions: Option<DateTime<Utc>>

When we last checked for and processed any new transactions.

This flag may be missing when an account has first connected, as it takes a few seconds for new transactions to be processed.

party: Option<DateTime<Utc>>

When we last fetched identity data about the party who has authenticated with the financial institution when connecting this account.

This data is updated by Akahu on a fixed 30 day interval, regardless of your app’s data refresh configuration.