pub struct TransactionMerchant {
pub id: MerchantId,
pub name: String,
pub website: Option<Url>,
}Expand description
Akahu defines a merchant as the business who was party to this transaction. For example, “The Warehouse” is a merchant.
Merchant data is provided as a name, an optional website, and a merchant
[https://developers.akahu.nz/docs/the-transaction-model#merchant]
Fields
id: MerchantIdA unique identifier for the merchant in the Akahu system.
Will always be prefixed with _merchant.
name: StringThe name of the merchant, for example “The Warehouse”.
website: Option<Url>The merchant’s website, if available.