pub struct TransactionMeta {
pub particulars: Option<String>,
pub code: Option<String>,
pub reference: Option<String>,
pub other_account: Option<BankAccountNumber>,
pub conversion: Option<TransactionConversion>,
pub card_suffix: Option<String>,
pub logo: Option<Url>,
}Expand description
This is other metadata that we extract from the transaction, including the following fields (where possible).
[https://developers.akahu.nz/docs/the-transaction-model#meta]
Fields
particulars: Option<String>Fields that are entered when a payment is made.
code: Option<String>Fields that are entered when a payment is made.
reference: Option<String>Fields that are entered when a payment is made.
other_account: Option<BankAccountNumber>The formatted NZ bank account number of the other party to this transaction.
conversion: Option<TransactionConversion>If this transaction was made in another currency, details about the currency conversion.
card_suffix: Option<String>If this transaction was made with a credit or debit card, we may be able to extract the card number used to make the transaction.
logo: Option<Url>URL of a .png image for this transaction. This is typically the logo of the transaction merchant. If no logo is available, a placeholder image is provided.