pub enum Active {
Active,
Inactive,
}Expand description
This attribute indicates the status of Akahu’s connection to this account.
It is possible for Akahu to lose the ability to authenticate with a financial institution if the user revokes Akahu’s access directly via their institution, or changes their login credentials, which in some cases can cause our long-lived access to be revoked.
Variants
Active
Akahu can authenticate with the institution to retrieve data and/or initiate payments for this account.
Inactive
Akahu no longer has access to this account. Your application will still be able to access Akahu’s cached copy of data for this account, but this will no longer be updated by refreshes. Write actions such as payments or transfers will no longer be available. Once an account is assigned the INACTIVE status, it will stay this way until the user re-establishes the connection. When your application observes an account with a status of INACTIVE, the user should be directed back to the Akahu OAuth flow or to [https://my.akahu.nz/connections] where they will be prompted to re-establish the connection.
Implementations